var plasma_entities = new Array(
    {
        id        : "plasma_frequency",
        name      : "Plasma frequency",
        dimension : "frequency",
        nspecies  : 1,
        section   : "waves",
        formula   : "return s1.getPlasmaFrequency()",
        wikiLink  : "Plasma_oscillation"
    },
    {
        id        : "gyrofrequency",
        name      : "Gyrofrequency",
        dimension : "frequency",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getGyroFrequency(this.plasma.B)",
        wikiLink  : "Cyclotron_resonance"
    },

    {
        id        : "wigner_seitz_radius",
        name      : "Typical inter-particle distance",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getTypicalDistance()",
        wikiLink  : "Wigner-Seitz_radius"
    },
    {
        id        : "debye_length",
        name      : "Debye length",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getDebyeLength()",
        wikiLink  : "Debye_length"
    },
    {
        id        : "full_debye_length",
        name      : "Full Debye length",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return this.plasma.getFullDebyeLength(s1)",
        wikiLink  : "Debye_length"
    },
    {
        id        : "gyroradius",
        name      : "Gyroradius",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getGyroRadius(this.plasma.B)",
        wikiLink  : "Gyroradius"
    },
    {
        id        : "distance_of_minimal_approach",
        name      : "Distance of minimal approach",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getMinApproachDistance()",
        wikiLink  : "Coulomb_collision"
    },
    {
        id        : "inertial_length",
        name      : "Inertial length",
        dimension : "length",
        nspecies  : 1,
        section   : "waves",
        formula   : "return s1.getInertialLength()",
        wikiLink  : "Inertial_length"
    },
    {
        id        : "de_broglie_wavelength",
        name      : "De Broglie wavelength",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getDeBroglieLength()",
        wikiLink  : "Matter_wave"
    },

    {
        id        : "thermal_velocity",
        name      : "Thermal velocity",
        dimension : "velocity",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getThermalVelocity()",
        wikiLink  : "Thermal_velocity"
    },
    {
        id        : "alfven_velocity",
        name      : "Alfven velocity",
        dimension : "velocity",
        nspecies  : 0,
        section   : "waves",
        formula   : "return this.plasma.getAlfvenVelocity(this.plasma.B)",
        wikiLink  : "Alfven_velocity"
    },
    {
        id        : "sound_velocity",
        name      : "Sound velocity",
        dimension : "velocity",
        nspecies  : 0,
        section   : "waves",
        formula   : "return this.plasma.getSoundVelocity()",
        wikiLink  : "Speed_of_sound"
    },

    {
        id        : "coupling_parameter",
        name      : "Coupling parameter",
        dimension : "none",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getCoupling()",
        wikiLink  : "Plasma_parameter"
    },
    {
        id        : "typical_debye_screening",
        name      : "Typical Debye screening",
        dimension : "none",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "var r = s1.getTypicalDistance()/s1.getDebyeLength(); \
                     return (1 + r)*Math.exp(-r)",
        wikiLink  : "Debye_length"
    },

    {
        id        : "transition_energy",
        name      : "Transition energy",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getTransitionEnergy()",
        wikiLink  : "Discrete_spectrum"
    },
    {
        id        : "natural_linewidth",
        name      : "Natural linewidth",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getNaturalWidth()",
        wikiLink  : "Spontaneous_emission"
    },
    {
        id        : "natural_linewidth_wl",
        name      : "Natural linewidth (wl)",
        dimension : "length",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.dE2dWl(this.plasma.r.getNaturalWidth())",
        wikiLink  : "Spontaneous_emission"
    },
    {
        id        : "Fine_structure",
        name      : "Fine structure",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getFineStructure()",
        wikiLink  : "Fine_structure"
    },
    {
        id        : "Fine_structure_wl",
        name      : "Fine structure (wl)",
        dimension : "length",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.dE2dWl(this.plasma.r.getFineStructure())",
        wikiLink  : "Fine_structure"
    },
    {
        id        : "doppler_fwhm",
        name      : "Doppler FWHM",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return 2*this.plasma.r.getDopplerHwhm()",
        wikiLink  : "Doppler_broadening"
    },
    {
        id        : "doppler_fwhm_wl",
        name      : "Doppler FWHM (wl)",
        dimension : "length",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.dE2dWl(2*this.plasma.r.getDopplerHwhm())",
        wikiLink  : "Doppler_broadening"
    },
    {
        id        : "zeeman_splitting",
        name      : "Zeeman splitting",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return 2*this.plasma.getZeemanSplitting()",
        wikiLink  : "Zeeman_effect"
    },
    {
        id        : "zeeman_splitting_wl",
        name      : "Zeeman splitting (wl)",
        dimension : "length",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.dE2dWl(2*this.plasma.getZeemanSplitting())",
        wikiLink  : "Zeeman_effect"
    },
    {
        id        : "total_stark_fwhm",
        name      : "Total Stark FWHM",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return 2*this.plasma.getTotalStarkHwhm()",
        wikiLink  : "Stark_effect"
    },
    {
        id        : "total_stark_fwhm_wl",
        name      : "Total Stark FWHM (wl)",
        dimension : "length",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.dE2dWl(2*this.plasma.getTotalStarkHwhm())",
        wikiLink  : "Stark_effect"
    },
    {
        id        : "stark_fwhm",
        name      : "Stark FWHM",
        dimension : "energy",
        nspecies  : 1,
        prepos    : "due to",
        section   : "spectroscopy",
        formula   : "return 2*this.plasma.getStarkHwhm(s1)",
        wikiLink  : "Stark_effect"
    },

    {
        id        : "qs_stark_fwhm",
        name      : "QS Stark FWHM",
        dimension : "energy",
        nspecies  : 1,
        prepos    : "due to",
        section   : "spectroscopy",
        formula   : "return 2*this.plasma.getQsHwhm(s1)"
    },

    {
        id        : "dynamic_stark_range",
        name      : "Dynamic Stark range",
        dimension : "energy",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "return this.plasma.getMicrofieldFrequency(s1)"
    },

    {
        id        : "minimal_energy_distance",
        name      : "Minimal energy distance",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getMinEnergyDistance()"
    },
    {
        id        : "plasmon_energy",
        name      : "Plasmon energy",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.e.getPlasmaFrequencyW()",
        wikiLink  : "Plasmon"
    },
    {
        id        : "fermi_energy",
        name      : "Fermi energy",
        dimension : "energy",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "return this.plasma.getFermiEnergy()",
        wikiLink  : "Fermi_energy"
    },
    {
        id        : "fermi_velocity",
        name      : "Fermi velocity",
        dimension : "velocity",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "return this.plasma.getFermiVelocity()",
        wikiLink  : "Fermi_energy"
    },
    {
        id        : "fermi_length",
        name      : "Fermi screening length",
        dimension : "length",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "return this.plasma.getFermiLength()",
        wikiLink  : "Electric-field_screening"
    },
    {
        id        : "chemical_potential",
        name      : "Chemical potential",
        dimension : "energy",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getChemicalPotential()",
        wikiLink  : "Chemical_potential"
    },

    {
        id        : "mass_density",
        name      : "Mass density",
        dimension : "mass_density",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getMassDensity()",
        wikiLink  : "Density"
    },
    {
        id        : "mass_density",
        name      : "Total mass density",
        dimension : "mass_density",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "return this.plasma.getMassDensity()",
        wikiLink  : "Density"
    },

    {
        id        : "beta",
        name      : "Beta",
        dimension : "none",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "return this.plasma.getBeta()",
        wikiLink  : "Beta_(plasma_physics)"
    },
    
    {
        id        : "transition_wavelength",
        name      : "Transition wavelength",
        dimension : "length",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return pf.base.Bohr.c/this.plasma.r.getTransitionEnergy()*(2*Math.PI)",
        wikiLink  : "Discrete_spectrum"
    },
    {
        id        : "transition_frequency",
        name      : "Transition frequency",
        dimension : "frequency",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getTransitionEnergy()/(2*Math.PI)",
        wikiLink  : "Discrete_spectrum"
    },

    {
        id        : "f_abs",
        name      : "Oscillator strength",
        dimension : "none",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getOscillatorStrength()",
        wikiLink  : "Oscillator_strength"
    },
    {
        id        : "A",
        name      : "Einstein coefficient",
        dimension : "frequency",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getEinsteinA()",
        wikiLink  : "Einstein_coefficients"
    },

    {
        id        : "LTE_parameter",
        name      : "LTE parameter",
        dimension : "none",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.e.getN()/this.plasma.getLteNe()",
        wikiLink  : "Local_thermodynamic_equilibrium"
    },
    
    {
        id        : "stark_quasistaticity",
        name      : "Stark quasistaticity",
        dimension : "none",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "return this.plasma.getStarkQuasistaticity(s1)"
    },
    {
        id        : "static_to_dynamic_stark_ratio",
        name      : "Static/dynamic Stark ratio",
        dimension : "none",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "return this.plasma.getStarkRatio(s1)"
    },

    {
        id        : "holtsmark_field",
        name      : "Holtsmark field",
        dimension : "efield",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "return s1.getHoltsmarkField()"
    },

    {
        id        : "microfield_frequency",
        name      : "Microfield frequency",
        dimension : "frequency",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "return this.plasma.getMicrofieldFrequency(s1)"
    },
    
    {
        id        : "cyclotron_losses",
        name      : "Cyclotron losses",
        dimension : "power_density",
        nspecies  : 1,
        section   : "radiation",
        formula   : "return s1.getCyclotronLosses(this.plasma.B)",
        wikiLink  : "Cyclotron_radiation"
    },
    
    {
        id        : "free-free_losses",
        name      : "Free-free losses",
        dimension : "power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "return this.plasma.getBremsstrahlungLosses()",
        wikiLink  : "Bremsstrahlung"
    },
    
    {
        id        : "dree-free_spectral_density",
        name      : "Free-free spectral density",
        dimension : "spectral_power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "return this.plasma.getBremsstrahlungSpectralDensity()",
        wikiLink  : "Bremsstrahlung"
    },
    
    {
        id        : "free-bound_losses",
        name      : "Free-bound losses",
        dimension : "power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "return this.plasma.getFreeBoundLosses()"
    },
    
    {
        id        : "free-bound_spectral_density",
        name      : "Free-bound spectral density",
        dimension : "spectral_power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "return this.plasma.getFreeBoundSpectralDensity()"
    },
    
    {
        id        : "ideal_gas_pressure",
        name      : "Ideal gas pressure",
        dimension : "pressure",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "return s1.getPressure()",
        wikiLink  : "Ideal_gas"
    },
    
    {
        id        : "total_pressure",
        name      : "Total gas pressure",
        dimension : "pressure",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "return this.plasma.getPressure()",
        wikiLink  : "Ideal_gas"
    },
    
    {
        id        : "magnetic_field_pressure",
        name      : "Magnetic field pressure",
        dimension : "pressure",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "return this.plasma.getMagneticFieldPressure()",
        wikiLink  : "Magnetic_pressure"
    },
    
    {
        id        : "coulomb_logarithm",
        name      : "Coulomb logarithm",
        dimension : "none",
        nspecies  : 2,
        section   : "collisions",
        formula   : "return this.plasma.getCoulombLog(s1, s2)",
        wikiLink  : "Coulomb_collision"
    },

    {
        id        : "relaxation_rate",
        name      : "Relaxation rate",
        dimension : "frequency",
        nspecies  : 2,
        section   : "collisions",
        formula   : "return this.plasma.getRelaxationRate(s1, s2)",
        wikiLink  : "Coulomb_collision"
    },

    {
        id        : "thomson_cross-section",
        name      : "Thomson cross-section",
        dimension : "area",
        nspecies  : 1,
        section   : "collisions",
        formula   : "return s1.getThomsonXsTotal()",
        wikiLink  : "Thomson_scattering"
    },

    {
        id        : "classical_ionization_field",
        name      : "Classical ionization field",
        dimension : "efield",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getClassicalIonizationField()"
    },
    {
        id        : "inglis_teller_field",
        name      : "Inglis-Teller field",
        dimension : "efield",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "return this.plasma.r.getInglisTellerField()",
        wikiLink  : "Inglis-Teller_equation"
    },
    {
        id        : "dreicer_field",
        name      : "Dreicer field",
        dimension : "efield",
        nspecies  : 0,
        section   : "collisions",
        formula   : "return this.plasma.getDreicerField()"
    }
);
